@@ -19,7 +19,8 @@
 #' @param x Table with individuals in the cdm.
 #' @param tableName Name of the table to intersect with. Options:
 #' visit_occurrence, condition_occurrence, drug_exposure, procedure_occurrence,
-#' device_exposure, measurement, observation, drug_era, condition_era, specimen.
+#' device_exposure, measurement, observation, drug_era, condition_era, specimen,
+#' episode.
 #' @param indexDate Variable in x that contains the date to compute the
 #' intersection.
 #' @param censorDate whether to censor overlap events at a specific date
@@ -54,6 +55,7 @@ addTableIntersectFlag <- function(x,
                                   nameStyle = "{table_name}_{window_name}",
                                   name = NULL) {
   cdm <- omopgenerics::cdmReference(x)
+  assertCharacter(tableName)
   checkCdm(cdm, tables = tableName)
   nameStyle <- gsub("\\{table_name\\}", tableName, nameStyle)
 
@@ -82,7 +84,8 @@ addTableIntersectFlag <- function(x,
 #' @param x Table with individuals in the cdm.
 #' @param tableName Name of the table to intersect with. Options:
 #' visit_occurrence, condition_occurrence, drug_exposure, procedure_occurrence,
-#' device_exposure, measurement, observation, drug_era, condition_era, specimen.
+#' device_exposure, measurement, observation, drug_era, condition_era, specimen,
+#' episode.
 #' @param indexDate Variable in x that contains the date to compute the
 #' intersection.
 #' @param censorDate whether to censor overlap events at a specific date
@@ -118,6 +121,7 @@ addTableIntersectCount <- function(x,
                                    nameStyle = "{table_name}_{window_name}",
                                    name = NULL) {
   cdm <- omopgenerics::cdmReference(x)
+  assertCharacter(tableName)
   checkCdm(cdm, tables = tableName)
   nameStyle <- gsub("\\{table_name\\}", tableName, nameStyle)
 
@@ -146,7 +150,8 @@ addTableIntersectCount <- function(x,
 #' @param x Table with individuals in the cdm.
 #' @param tableName Name of the table to intersect with. Options:
 #' visit_occurrence, condition_occurrence, drug_exposure, procedure_occurrence,
-#' device_exposure, measurement, observation, drug_era, condition_era, specimen.
+#' device_exposure, measurement, observation, drug_era, condition_era, specimen,
+#' episode.
 #' @param indexDate Variable in x that contains the date to compute the
 #' intersection.
 #' @param censorDate whether to censor overlap events at a specific date
@@ -182,6 +187,7 @@ addTableIntersectDate <- function(x,
                                   nameStyle = "{table_name}_{window_name}",
                                   name = NULL) {
   cdm <- omopgenerics::cdmReference(x)
+  assertCharacter(tableName)
   checkCdm(cdm, tables = tableName)
   nameStyle <- gsub("\\{table_name\\}", tableName, nameStyle)
 
@@ -210,7 +216,8 @@ addTableIntersectDate <- function(x,
 #' @param x Table with individuals in the cdm.
 #' @param tableName Name of the table to intersect with. Options:
 #' visit_occurrence, condition_occurrence, drug_exposure, procedure_occurrence,
-#' device_exposure, measurement, observation, drug_era, condition_era, specimen.
+#' device_exposure, measurement, observation, drug_era, condition_era, specimen,
+#' episode.
 #' @param indexDate Variable in x that contains the date to compute the
 #' intersection.
 #' @param censorDate whether to censor overlap events at a specific date
@@ -246,6 +253,7 @@ addTableIntersectDays <- function(x,
                                   nameStyle = "{table_name}_{window_name}",
                                   name = NULL) {
   cdm <- omopgenerics::cdmReference(x)
+  assertCharacter(tableName)
   checkCdm(cdm, tables = tableName)
   nameStyle <- gsub("\\{table_name\\}", tableName, nameStyle)
 
@@ -276,7 +284,8 @@ addTableIntersectDays <- function(x,
 #' @param x Table with individuals in the cdm.
 #' @param tableName Name of the table to intersect with. Options:
 #' visit_occurrence, condition_occurrence, drug_exposure, procedure_occurrence,
-#' device_exposure, measurement, observation, drug_era, condition_era, specimen.
+#' device_exposure, measurement, observation, drug_era, condition_era, specimen,
+#' episode.
 #' @param field The columns from the table in tableName to intersect over.
 #' For example, if the user uses visit_occurrence in tableName then for field the possible
 #' options include visit_occurrence_id, visit_concept_id, visit_type_concept_id.
@@ -319,6 +328,7 @@ addTableIntersectField <- function(x,
                                    nameStyle = "{table_name}_{extra_value}_{window_name}",
                                    name = NULL) {
   cdm <- omopgenerics::cdmReference(x)
+  assertCharacter(tableName)
   checkCdm(cdm, tables = tableName)
   nameStyle <- gsub("\\{table_name\\}", tableName, nameStyle)
   nameStyle <- gsub("\\{extra_value\\}", "\\{value\\}", nameStyle)
