@@ -1,10 +1,27 @@
-test_that("addAttributes, functionality", {
+test_that("attributes and classes are kept", {
   skip_on_cran()
-  cdm <- mockPatientProfiles(connectionDetails)
+  cdm <- mockPatientProfiles(con = connection(), writeSchema = writeSchema())
+
+  oldCohort <- cdm$cohort1
+  newCohort <- cdm$cohort1 %>% addDemographics()
+
+  expect_true(length(attributes(newCohort)) == length(attributes(oldCohort)))
+  for (i in names(attributes(newCohort))) {
+    if (i != "tbl_name") {
+      x <- attr(newCohort, i)
+      y <- attr(oldCohort, i)
+      if (i == "class") {
+        x <- x[x != "GeneratedCohortSet"]
+        y <- y[y != "GeneratedCohortSet"]
+      }
+      expect_true(identical(x, y))
+    }
+  }
 
   oldCohort <- cdm$cohort1
   newCohort <- cdm$cohort1 %>%
-    addDemographics()
+    addCohortIntersectFlag(targetCohortTable = "cohort2") |>
+    addTableIntersectCount(tableName = "condition_occurrence")
 
   expect_true(length(attributes(newCohort)) == length(attributes(oldCohort)))
   for (i in names(attributes(newCohort))) {
@@ -15,26 +32,9 @@ test_that("addAttributes, functionality", {
         x <- x[x != "GeneratedCohortSet"]
         y <- y[y != "GeneratedCohortSet"]
       }
-      expect_true(identical(x ,y))
+      expect_true(identical(x, y))
     }
   }
 
-  oldCohort <- cdm$cohort1
-  expect_warning(
-    newCohort <- cdm$cohort1 %>%
-      addCohortIntersect(targetCohortTable = "cohort2")
-  )
-
-  expect_true(length(attributes(newCohort)) == length(attributes(oldCohort)))
-  for (i in names(attributes(newCohort))) {
-    if (i != "tbl_name") {
-      x <- attr(newCohort, i)
-      y <- attr(oldCohort, i)
-      if (i == "class") {
-        x <- x[x != "GeneratedCohortSet"]
-        y <- y[y != "GeneratedCohortSet"]
-      }
-      expect_true(identical(x ,y))
-    }
-  }
+  mockDisconnect(cdm = cdm)
 })
