@@ -1,4 +1,5 @@
 test_that("addInObservtaion, Inf windows, completeInterval T", {
+  skip_on_cran()
   cdm <- mockPatientProfiles(con = connection(), writeSchema = writeSchema())
   expect_no_error(
     cdm$cohort1 %>%
@@ -20,6 +21,7 @@ test_that("addInObservtaion, Inf windows, completeInterval T", {
 })
 
 test_that("addDemographics, input length, type", {
+  skip_on_cran()
   cdm <- mockPatientProfiles(
     con = connection(),
     writeSchema = writeSchema(),
@@ -94,8 +96,10 @@ test_that("addDemographics, cohort and condition_occurrence", {
   )
   expect_identical(
     x$sex,
-    c("Male", "Male", "Female", "Female", "Female", "Female", "Female",
-      "Female", "Male", "Male", "Male", "Male", "Male", "Male", "Male", "Male")
+    c(
+      "Male", "Male", "Female", "Female", "Female", "Female", "Female",
+      "Female", "Male", "Male", "Male", "Male", "Male", "Male", "Male", "Male"
+    )
   )
   expect_identical(
     x$prior_observation,
@@ -194,8 +198,10 @@ test_that("partial demographics - cohorts", {
   # age and age group
   expect_equal(
     colnames(cdm$cohort1a),
-    c("cohort_definition_id", "subject_id", "cohort_start_date",
-      "cohort_end_date", "age")
+    c(
+      "cohort_definition_id", "subject_id", "cohort_start_date",
+      "cohort_end_date", "age"
+    )
   )
 
   # only sex
@@ -210,8 +216,10 @@ test_that("partial demographics - cohorts", {
     )
   expect_equal(
     colnames(cdm$cohort1b),
-    c("cohort_definition_id", "subject_id", "cohort_start_date",
-      "cohort_end_date", "sex")
+    c(
+      "cohort_definition_id", "subject_id", "cohort_start_date",
+      "cohort_end_date", "sex"
+    )
   )
 
   # only prior history
@@ -226,8 +234,10 @@ test_that("partial demographics - cohorts", {
     )
   expect_equal(
     colnames(cdm$cohort1c),
-    c("cohort_definition_id", "subject_id", "cohort_start_date",
-      "cohort_end_date", "prior_observation")
+    c(
+      "cohort_definition_id", "subject_id", "cohort_start_date",
+      "cohort_end_date", "prior_observation"
+    )
   )
 
   # only future observation
@@ -242,8 +252,10 @@ test_that("partial demographics - cohorts", {
     )
   expect_equal(
     colnames(cdm$cohort1d),
-    c("cohort_definition_id", "subject_id", "cohort_start_date",
-      "cohort_end_date", "future_observation")
+    c(
+      "cohort_definition_id", "subject_id", "cohort_start_date",
+      "cohort_end_date", "future_observation"
+    )
   )
 
 
@@ -260,9 +272,11 @@ test_that("partial demographics - cohorts", {
   # age and age group
   expect_equal(
     colnames(cdm$cohort1e),
-    c("cohort_definition_id", "subject_id", "cohort_start_date",
+    c(
+      "cohort_definition_id", "subject_id", "cohort_start_date",
       "cohort_end_date", "age", "age_group", "sex", "prior_observation",
-      "future_observation")
+      "future_observation"
+    )
   )
 })
 
@@ -367,6 +381,7 @@ test_that("priorObservation and future_observation - outside of observation peri
 })
 
 test_that("priorObservation - multiple observation periods", {
+  skip_on_cran()
   # with multiple observation periods,
   # prior history should relate to the most recent observation start date
 
@@ -433,6 +448,7 @@ test_that("priorObservation - multiple observation periods", {
 })
 
 test_that("check that no extra rows are added", {
+  skip_on_cran()
   cohort1 <- dplyr::tibble(
     cohort_definition_id = c(1, 2, 1, 2, 1),
     subject_id = c(1, 1, 1, 1, 1),
@@ -698,6 +714,7 @@ test_that("multiple cohortIds, check age at cohort end", {
 })
 
 test_that("age group checks", {
+  skip_on_cran()
   cohort1 <- dplyr::tibble(
     cohort_definition_id = 1:3,
     subject_id = 1:3,
@@ -846,6 +863,7 @@ test_that("age group checks", {
 })
 
 test_that("age variable names", {
+  skip_on_cran()
   cdm <- mockPatientProfiles(con = connection(), writeSchema = writeSchema())
 
   result <- addAge(
@@ -863,6 +881,7 @@ test_that("age variable names", {
 })
 
 test_that("expected errors", {
+  skip_on_cran()
   # check input length and type for each of the arguments
   cdm <- mockPatientProfiles(
     con = connection(),
@@ -974,6 +993,7 @@ test_that("expected errors", {
 })
 
 test_that("addCategories input", {
+  skip_on_cran()
   cdm <- mockPatientProfiles(
     con = connection(),
     writeSchema = writeSchema(),
@@ -1052,6 +1072,7 @@ test_that("addCategories input", {
 })
 
 test_that("test if column exist, overwrite", {
+  skip_on_cran()
   cohort1 <- dplyr::tibble(
     cohort_definition_id = c(1, 1, 1, 1, 1),
     subject_id = c(1, 1, 1, 2, 2),
@@ -1163,6 +1184,7 @@ test_that("test if column exist, overwrite", {
 })
 
 test_that("date of birth", {
+  skip_on_cran()
   person <- dplyr::tibble(
     person_id = 1:2,
     gender_concept_id = 8507,
@@ -1227,6 +1249,7 @@ test_that("date of birth", {
 })
 
 test_that("missing levels", {
+  skip_on_cran()
   cdm <- mockPatientProfiles(con = connection(), writeSchema = writeSchema())
 
   result <- cdm[["cohort1"]] %>%
@@ -1252,6 +1275,7 @@ test_that("missing levels", {
 })
 
 test_that("overwriting obs period variables", {
+  skip_on_cran()
   cdm <- mockPatientProfiles(con = connection(), writeSchema = writeSchema())
 
   cdm$cohort1 <- cdm$cohort1 %>%
@@ -1275,10 +1299,10 @@ test_that("overwriting obs period variables", {
     cdm$cohort2 |> dplyr::pull("observation_period_start_date") |> unique(),
     "a"
   )
-
 })
 
 test_that("addDemographics, date of birth option", {
+  skip_on_cran()
   cdm <- mockPatientProfiles(con = connection(), writeSchema = writeSchema())
   expect_no_error(x <- cdm$cohort1 |> addDemographics(dateOfBirth = T))
   expect_true("date_of_birth" %in% colnames(x))
@@ -1294,16 +1318,18 @@ test_that("addDemographics, date of birth option", {
 })
 
 test_that("allow NA as age_group", {
+  skip_on_cran()
   cdm <- mockPatientProfiles(con = connection(), writeSchema = writeSchema())
   expect_no_error(
     cdm$cohort1 <- cdm$cohort1 |>
-      addAge(ageGroup = list(c(0,0)), missingAgeGroupValue = NA_character_)
+      addAge(ageGroup = list(c(0, 0)), missingAgeGroupValue = NA_character_)
   )
   expect_true(all(is.na(cdm$cohort1 |> dplyr::pull("age_group"))))
   mockDisconnect(cdm = cdm)
 })
 
 test_that("allow age_group only", {
+  skip_on_cran()
   cdm <- mockPatientProfiles(con = connection(), writeSchema = writeSchema())
   expect_no_error(
     cdm$cohort1 <- cdm$cohort1 |>
@@ -1321,27 +1347,29 @@ test_that("allow age_group only", {
 })
 
 test_that("query gives same result as main function", {
+  skip_on_cran()
   cdm <- mockPatientProfiles(con = connection(), writeSchema = writeSchema())
- # we should get the same results if compute was internal or not
- result_1 <- cdm$cohort1 %>%
+  # we should get the same results if compute was internal or not
+  result_1 <- cdm$cohort1 %>%
     PatientProfiles::addDemographics() %>%
     dplyr::collect()
- result_2 <- cdm$cohort1 %>%
+  result_2 <- cdm$cohort1 %>%
     addDemographicsQuery() |>
     dplyr::collect()
- expect_equal(result_1, result_2)
+  expect_equal(result_1, result_2)
 
- # check no tables are created along the way with query
- start_tables <- CDMConnector::listSourceTables(cdm)
- cdm$cohort1 %>%
-   addDemographicsQuery()
- end_tables <- CDMConnector::listSourceTables(cdm)
- expect_equal(start_tables, end_tables)
+  # check no tables are created along the way with query
+  start_tables <- CDMConnector::listSourceTables(cdm)
+  cdm$cohort1 %>%
+    addDemographicsQuery()
+  end_tables <- CDMConnector::listSourceTables(cdm)
+  expect_equal(start_tables, end_tables)
 
- mockDisconnect(cdm)
+  mockDisconnect(cdm)
 })
 
 test_that("table names", {
+  skip_on_cran()
   cdm <- mockPatientProfiles(con = connection(), writeSchema = writeSchema())
   # we should get the same results if compute was internal or not
 
