@@ -25,6 +25,7 @@ test_that("basic structures", {
 })
 
 test_that("input validation", {
+  skip_on_cran()
   cdm <- mockPatientProfiles(con = connection(), writeSchema = writeSchema())
   expect_error(expect_warning(cdm$cohort1 %>%
     addTableIntersect(
@@ -108,10 +109,15 @@ test_that("input validation", {
 
 test_that("addTableIntersectCount example", {
   cohort1 <- dplyr::tibble(
-    cohort_definition_id = c(1, 1, 1, 1, 1),
-    subject_id = c(1, 1, 1, 1, 1),
+    cohort_definition_id = c(1, 1, 1, 1, 1, 2, 2, 2, 2, 2),
+    subject_id = c(1, 1, 1, 1, 1, 1, 1, 1, 1, 1),
     cohort_start_date = as.Date(
       c(
+        "2020-01-01",
+        "2021-01-15",
+        "2022-01-20",
+        "2023-01-01",
+        "2024-02-01",
         "2020-01-01",
         "2021-01-15",
         "2022-01-20",
@@ -168,14 +174,14 @@ test_that("addTableIntersectCount example", {
 
   expect_identical(
     de_count |> nrow() %>% as.numeric(),
-    5
+    10
   )
 
   expect_true("drug_exposure_m50_to_50" %in%
     (colnames(de_count)))
 
   expect_identical(
-    de_count %>%
+    de_count %>% dplyr::filter(cohort_definition_id == 1) %>%
       dplyr::filter(cohort_start_date == "2020-01-01") %>%
       dplyr::pull("drug_exposure_m50_to_50") %>%
       as.numeric(),
@@ -184,11 +190,12 @@ test_that("addTableIntersectCount example", {
 
   expect_true(all((de_count %>%
     dplyr::filter(!cohort_start_date == "2020-01-01") %>%
+    dplyr::filter(cohort_start_date == "2020-01-01") %>%
     dplyr::pull("drug_exposure_m50_to_50") %>%
     as.numeric()) == 0))
 
   expect_identical(
-    de_count %>%
+    de_count %>% dplyr::filter(cohort_start_date == "2020-01-01") %>%
       dplyr::filter(cohort_start_date == "2009-01-01") |>
       nrow() |>
       as.numeric(),
@@ -199,6 +206,7 @@ test_that("addTableIntersectCount example", {
 })
 
 test_that("addTableIntersectFlag example", {
+  skip_on_cran()
   cohort1 <- dplyr::tibble(
     cohort_definition_id = c(1, 1, 1, 1, 1),
     subject_id = c(1, 1, 1, 1, 1),
@@ -305,6 +313,7 @@ test_that("addTableIntersectFlag example", {
 })
 
 test_that("addTableIntersectDate example", {
+  skip_on_cran()
   cohort1 <- dplyr::tibble(
     cohort_definition_id = c(1, 1, 1, 1, 1),
     subject_id = c(1, 1, 1, 1, 1),
@@ -439,6 +448,7 @@ test_that("addTableIntersectDate example", {
 })
 
 test_that("addTableIntersectDays example", {
+  skip_on_cran()
   cohort1 <- dplyr::tibble(
     cohort_definition_id = c(1, 1, 1, 1, 1),
     subject_id = c(1, 1, 1, 1, 1),
@@ -568,6 +578,7 @@ test_that("addTableIntersectDays example", {
 })
 
 test_that("addTableIntersectFields example", {
+  skip_on_cran()
   cohort1 <- dplyr::tibble(
     cohort_definition_id = c(1, 1, 1, 1, 1),
     subject_id = c(1, 1, 1, 1, 1),
